@@ -9,6 +9,7 @@ ALIASES = {
     "break": ("brk",),
     "exit": ("exit_group",),
     "fcntl": ("fcntl64",),
+    "getcwd": ("__getcwd",),
 }
 
 # Name of arguments containing a filename or a path
@@ -280,7 +281,7 @@ SYSCALL_PROTOTYPES = {
             ("struct user_desc*", "newtls"),
             ("void*", "child_tidptr"),
         )),
-    "__getcwd": ("long", (
+    "getcwd": ("long", (
             ("char*", "pathname"),
             ("size_t", "size"),
         )),
@@ -467,7 +468,7 @@ SYSCALL_PROTOTYPES = {
         )),
 }
 
-for orig, copies in ALIASES.iteritems():
+for orig, copies in ALIASES.items():
     orig = SYSCALL_PROTOTYPES[orig]
     for copy in copies:
         SYSCALL_PROTOTYPES[copy] = orig
